@@ -19,7 +19,7 @@
 #' }
 read_text <- function(filename, delimiter = NULL, first_column_names = NULL, dtype = "float32") {
   python_anndata <- reticulate::import("anndata", convert = FALSE)
-  py_to_r(python_anndata$read_text(
+  py_to_r_ifneedbe(python_anndata$read_text(
     filename = filename,
     delimiter = delimiter,
     first_column_names = first_column_names,
